@@ -731,7 +731,7 @@ void iAnimatorScript::LogoPosition(iValue* v0, Assignment, iString *pErrorMessag
 //
 //  Manipulation of VTK windows
 //
-void iAnimatorScript::SetCurrentVTK(iValue* v0, iScriptType::Assignment rel, iString *pErrorMessage)
+void iAnimatorScript::SetCurrentVTK(iValue* v0, iScriptType::Assignment, iString *pErrorMessage)
 {
 	int v;
 	UPDATE_VALUE_ABS(v0,v); v--;
