@@ -969,7 +969,7 @@ int iDataReader::loadPartBinFile(const iString &fname)
 //    10:   not enough memory for the data
 //
 //
-	int i, j, ret;
+	int i, ret;
 	iString s;
 	vtkIdType ntot = 0, l, l0, loff;
 	int ntemp;
@@ -995,7 +995,7 @@ int iDataReader::loadPartBinFile(const iString &fname)
 		ntot = ntemp;
 	}
 	if(F.readBlock((char *)&ntemp,4) != 4) err = true;
-    if(ntot<0 || ntot>1000000000) err = true;
+    if(ntot<=0 || ntot>1000000000) err = true;
 	if(err) { F.close(); return 2; }
 
 	if(F.readBlock((char *)&ntemp,4) != 4) err = true;
@@ -1204,8 +1204,7 @@ int iDataReader::loadPartBinFile(const iString &fname)
 					loff = i + 3*l;
 					if(limits[0][0]->periodic[i])
 					{
-						for(j=0; j<999 && xptrF[loff]> 1.0; j++) xptrF[loff] -= 2.0;
-						for(j=0; j<999 && xptrF[loff]<-1.0; j++) xptrF[loff] += 2.0;
+						xptrF[loff] -= 2.0*floor(0.5*(1.0+xptrF[loff]));
 					}
 				}
 			}
@@ -1219,8 +1218,7 @@ int iDataReader::loadPartBinFile(const iString &fname)
 					loff = i + 3*l;
 					if(limits[0][0]->periodic[i])
 					{
-						for(j=0; j<999 && xptrD[loff]> 1.0; j++) xptrD[loff] -= 2.0;
-						for(j=0; j<999 && xptrD[loff]<-1.0; j++) xptrD[loff] += 2.0;
+						xptrD[loff] -= 2.0*floor(0.5*(1.0+xptrD[loff]));
 					}
 				}
 			}
@@ -1290,7 +1288,8 @@ int iDataReader::loadPartTxtFile(const iString &fname)
 //
 	int i, ret;
 	iString s;
-	vtkIdType ntot, l, l0;
+	long ntot;
+	vtkIdType l, l0;
 	iFile F;
 	bool err;
 	double llD[3], urD[3], xyzD[3], fD[99];
@@ -1321,9 +1320,9 @@ int iDataReader::loadPartTxtFile(const iString &fname)
 	if(newPoints == 0) reportNullPointer(8220);
 
 	if(F.readLine(s,1024) == -1) err = true;
-	ret = sscanf(s.latin1(),"%d",&ntot);
+	ret = sscanf(s.latin1(),"%ld",&ntot);
 	if(ret != 1) err = true;
-    if(ntot<0 || ntot>1000000000) err = true;
+    if(ntot<=0 || ntot>1000000000) err = true;
 	if(err) { F.close(); return 2; }
 
 	for(i=0; i<3; i++) axisName[i] = new char[8192];
@@ -1501,7 +1500,6 @@ int iDataReader::loadPartTxtFile(const iString &fname)
 	if(limits[0][0]->periodicBC)
 	{
 		vtkIdType loff;
-		int j;
 		if(pointsAreFloat)
 		{
 			float *xptrF = (float *)newPoints->GetVoidPointer(0);
@@ -1512,8 +1510,7 @@ int iDataReader::loadPartTxtFile(const iString &fname)
 					loff = i + 3*l;
 					if(limits[0][0]->periodic[i])
 					{
-						for(j=0; j<999 && xptrF[loff]> 1.0; j++) xptrF[loff] -= 2.0;
-						for(j=0; j<999 && xptrF[loff]<-1.0; j++) xptrF[loff] += 2.0;
+						xptrF[loff] -= 2.0*floor(0.5*(1.0+xptrF[loff]));
 					}
 				}
 			}
@@ -1528,8 +1525,7 @@ int iDataReader::loadPartTxtFile(const iString &fname)
 					loff = i + 3*l;
 					if(limits[0][0]->periodic[i])
 					{
-						for(j=0; j<999 && xptrD[loff]> 1.0; j++) xptrD[loff] -= 2.0;
-						for(j=0; j<999 && xptrD[loff]<-1.0; j++) xptrD[loff] += 2.0;
+						xptrD[loff] -= 2.0*floor(0.5*(1.0+xptrD[loff]));
 					}
 				}
 			}
