@@ -738,7 +738,7 @@ void ViewWidget::contentsMousePressEvent(QMouseEvent* e)
 }
 
 
-void ViewWidget::contentsMouseReleaseEvent(QMouseEvent* e)
+void ViewWidget::contentsMouseReleaseEvent(QMouseEvent *)
 {
 	if(moving!=0 && moving->vtk!=0)
 	{
