@@ -106,7 +106,7 @@ namespace iDialogVariablesExplorer_private
 	{
 		w->clear();
 		w->insertItem(QString::number((double)val,'g',3));
-		w->insertItem("Cell: "+QString::number(cell));
+		w->insertItem("Cell: "+QString::number((long)cell));
 		w->insertItem("at X: "+QString::number(pos[0]));
 		w->insertItem("at Y: "+QString::number(pos[1]));
 		w->insertItem("at Z: "+QString::number(pos[2]));
