@@ -1875,7 +1875,7 @@ int iVTK::dumpImage(int m, vtkImageData *data)
 }
 
 
-void iVTK::computePositionShiftsUnderMagnification(int winij[2], vtkViewport *viewport)
+void iVTK::computePositionShiftsUnderMagnification(int winij[2], vtkViewport *)
 {
 	int i;
 	vtkCamera *cam = ren->GetActiveCamera();
